# system configuration generated and used by the sysconfig module
build_time_vars = {
    "ABIFLAGS": "",
    "ABI_THREAD": "",
    "AC_APPLE_UNIVERSAL_BUILD": 0,
    "AIX_BUILDDATE": 0,
    "AIX_GENUINE_CPLUSPLUS": 0,
    "ALIGNOF_LONG": 8,
    "ALIGNOF_MAX_ALIGN_T": 16,
    "ALIGNOF_SIZE_T": 8,
    "ALT_SOABI": 0,
    "ANDROID_API_LEVEL": 0,
    "APP_STORE_COMPLIANCE_PATCH": "",
    "AR": "/tools/llvm/bin/llvm-ar",
    "ARFLAGS": "rcs",
    "BASECFLAGS": "-fno-strict-overflow -Wsign-compare -Wunreachable-code",
    "BASECPPFLAGS": "",
    "BASEMODLIBS": "",
    "BINDIR": "/install/bin",
    "BINLIBDEST": "/install/lib/python3.13",
    "BLDLIBRARY": "-L. -lpython3.13",
    "BLDSHARED": "clang -pthread -shared -Wl,-z,noexecstack  -Wl,--exclude-libs,ALL ",
    "BOOTSTRAP_HEADERS": "\\",
    "BUILDEXE": "",
    "BUILDPYTHON": "python",
    "BUILD_GNU_TYPE": "x86_64-unknown-linux-gnu",
    "BUILD_SCRIPTS_DIR": "build/scripts-3.13",
    "BYTESTR_DEPS": "\\",
    "CC": "clang -pthread",
    "CCSHARED": "-fPIC",
    "CFLAGS": "-fno-strict-overflow -Wsign-compare -Wunreachable-code -DNDEBUG -g -O3 -Wall -O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC  ",
    "CFLAGSFORSHARED": "-fPIC",
    "CFLAGS_ALIASING": "-fno-strict-aliasing",
    "CODECS_COMMON_HEADERS": "./Modules/cjkcodecs/multibytecodec.h ./Modules/cjkcodecs/cjkcodecs.h",
    "COMPILEALL_OPTS": "-j0",
    "CONFIGFILES": "configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in",
    "CONFIGURE_CFLAGS": "-O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC  ",
    "CONFIGURE_CFLAGS_NODIST": "-D_Py_TIER2=3 -D_Py_JIT -flto=thin -g -fno-pie -std=c11 -Wextra -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -fvisibility=hidden",
    "CONFIGURE_CPPFLAGS": "-O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC  ",
    "CONFIGURE_LDFLAGS": "-Wl,-z,noexecstack  -Wl,--exclude-libs,ALL ",
    "CONFIGURE_LDFLAGS_NODIST": "-flto=thin -g -Wl,--emit-relocs",
    "CONFIGURE_LDFLAGS_NOLTO": "-flto=thin",
    "CONFIG_ARGS": "'--build=x86_64-unknown-linux-gnu' '--host=x86_64-unknown-linux-gnu' '--prefix=/install' '--with-openssl=/tools/deps' '--with-system-expat' '--with-system-libmpdec' '--without-ensurepip' '--with-readline=editline' '--enable-static-libpython-for-interpreter' '--enable-shared' '--with-mimalloc' '--enable-optimizations' '--enable-bolt' '--enable-experimental-jit=yes-off' '--with-lto' '--with-build-python=/tools/host/bin/python3.13' '--with-dbmliborder=bdb' 'build_alias=x86_64-unknown-linux-gnu' 'host_alias=x86_64-unknown-linux-gnu' 'PKG_CONFIG=pkg-config --static' 'PKG_CONFIG_PATH=/tools/deps/share/pkgconfig:/tools/deps/lib/pkgconfig' 'CC=clang' 'CFLAGS=-O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC  ' 'LDFLAGS=-Wl,-z,noexecstack  -Wl,--exclude-libs,ALL ' 'CPPFLAGS=-O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC  ' 'PROFILE_TASK=-m test --pgo -j 4 --ignore test.test_bytes.BytesTest.test_from_format'",
    "CONFINCLUDEDIR": "/install/include",
    "CONFINCLUDEPY": "/install/include/python3.13",
    "COREPYTHONPATH": "",
    "COVERAGE_INFO": "/build/Python-3.13.14/coverage.info",
    "COVERAGE_LCOV_OPTIONS": "--rc lcov_branch_coverage=1",
    "COVERAGE_REPORT": "/build/Python-3.13.14/lcov-report",
    "COVERAGE_REPORT_OPTIONS": "--rc lcov_branch_coverage=1 --branch-coverage --title \"CPython 3.13 LCOV report [commit $(shell )]\"",
    "CPPFLAGS": "-I. -I./Include -O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC  ",
    "CXX": "clang++ -pthread",
    "DESTDIRS": "/install /install/lib /install/lib/python3.13 /install/lib/python3.13/lib-dynload",
    "DESTLIB": "/install/lib/python3.13",
    "DESTPATH": "",
    "DESTSHARED": "/install/lib/python3.13/lib-dynload",
    "DFLAGS": "",
    "DIRMODE": 755,
    "DIST": "README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in Include Lib Misc Ext-dummy",
    "DISTDIRS": "Include Lib Misc Ext-dummy",
    "DISTFILES": "README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in",
    "DLINCLDIR": ".",
    "DLLLIBRARY": "",
    "DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754": 0,
    "DOUBLE_IS_BIG_ENDIAN_IEEE754": 0,
    "DOUBLE_IS_LITTLE_ENDIAN_IEEE754": 1,
    "DSYMUTIL": "",
    "DSYMUTIL_PATH": "",
    "DTRACE": "",
    "DTRACE_DEPS": "\\",
    "DTRACE_HEADERS": "",
    "DTRACE_OBJS": "",
    "DYNLOADFILE": "dynload_shlib.o",
    "ENABLE_IPV6": 1,
    "ENSUREPIP": "no",
    "EXE": "",
    "EXEMODE": 755,
    "EXENAME": "/install/bin/python3.13",
    "EXPORTSFROM": "",
    "EXPORTSYMS": "",
    "EXTRATESTOPTS": "",
    "EXTRA_CFLAGS": "",
    "EXT_SUFFIX": ".cpython-313-x86_64-linux-gnu.so",
    "FILEMODE": 644,
    "FREEZE_MODULE": "/tools/host/bin/python3.13 ./Programs/_freeze_module.py",
    "FREEZE_MODULE_BOOTSTRAP": "/tools/host/bin/python3.13 ./Programs/_freeze_module.py",
    "FREEZE_MODULE_BOOTSTRAP_DEPS": "./Programs/_freeze_module.py",
    "FREEZE_MODULE_DEPS": "./Programs/_freeze_module.py",
    "FROZEN_FILES_IN": "\\",
    "FROZEN_FILES_OUT": "\\",
    "GETPGRP_HAVE_ARG": 0,
    "GITBRANCH": "",
    "GITTAG": "",
    "GITVERSION": "",
    "GNULD": "yes",
    "HAVE_ACCEPT": 1,
    "HAVE_ACCEPT4": 1,
    "HAVE_ACOSH": 1,
    "HAVE_ADDRINFO": 1,
    "HAVE_ALARM": 1,
    "HAVE_ALIGNED_REQUIRED": 0,
    "HAVE_ALLOCA_H": 1,
    "HAVE_ALTZONE": 0,
    "HAVE_ASINH": 1,
    "HAVE_ASM_TYPES_H": 1,
    "HAVE_ATANH": 1,
    "HAVE_BIND": 1,
    "HAVE_BIND_TEXTDOMAIN_CODESET": 1,
    "HAVE_BLUETOOTH_BLUETOOTH_H": 0,
    "HAVE_BLUETOOTH_H": 0,
    "HAVE_BROKEN_MBSTOWCS": 0,
    "HAVE_BROKEN_NICE": 0,
    "HAVE_BROKEN_PIPE_BUF": 0,
    "HAVE_BROKEN_POLL": 0,
    "HAVE_BROKEN_POSIX_SEMAPHORES": 0,
    "HAVE_BROKEN_PTHREAD_SIGMASK": 0,
    "HAVE_BROKEN_SEM_GETVALUE": 0,
    "HAVE_BROKEN_UNSETENV": 0,
    "HAVE_BUILTIN_ATOMIC": 1,
    "HAVE_BZLIB_H": 1,
    "HAVE_CHFLAGS": 0,
    "HAVE_CHMOD": 1,
    "HAVE_CHOWN": 1,
    "HAVE_CHROOT": 1,
    "HAVE_CLOCK": 1,
    "HAVE_CLOCK_GETRES": 1,
    "HAVE_CLOCK_GETTIME": 1,
    "HAVE_CLOCK_NANOSLEEP": 1,
    "HAVE_CLOCK_SETTIME": 1,
    "HAVE_CLOCK_T": 1,
    "HAVE_CLOSEFROM": 0,
    "HAVE_CLOSE_RANGE": 0,
    "HAVE_COMPUTED_GOTOS": 1,
    "HAVE_CONFSTR": 1,
    "HAVE_CONIO_H": 0,
    "HAVE_CONNECT": 1,
    "HAVE_COPY_FILE_RANGE": 0,
    "HAVE_CTERMID": 1,
    "HAVE_CTERMID_R": 0,
    "HAVE_CURSES_FILTER": 1,
    "HAVE_CURSES_H": 1,
    "HAVE_CURSES_HAS_KEY": 1,
    "HAVE_CURSES_IMMEDOK": 1,
    "HAVE_CURSES_IS_PAD": 1,
    "HAVE_CURSES_IS_TERM_RESIZED": 1,
    "HAVE_CURSES_RESIZETERM": 1,
    "HAVE_CURSES_RESIZE_TERM": 1,
    "HAVE_CURSES_SYNCOK": 1,
    "HAVE_CURSES_TYPEAHEAD": 1,
    "HAVE_CURSES_USE_ENV": 1,
    "HAVE_CURSES_WCHGAT": 1,
    "HAVE_DB_H": 1,
    "HAVE_DECL_RTLD_DEEPBIND": 1,
    "HAVE_DECL_RTLD_GLOBAL": 1,
    "HAVE_DECL_RTLD_LAZY": 1,
    "HAVE_DECL_RTLD_LOCAL": 1,
    "HAVE_DECL_RTLD_MEMBER": 0,
    "HAVE_DECL_RTLD_NODELETE": 1,
    "HAVE_DECL_RTLD_NOLOAD": 1,
    "HAVE_DECL_RTLD_NOW": 1,
    "HAVE_DECL_TZNAME": 0,
    "HAVE_DECL_UT_NAMESIZE": 1,
    "HAVE_DEVICE_MACROS": 1,
    "HAVE_DEV_PTC": 0,
    "HAVE_DEV_PTMX": 1,
    "HAVE_DIRECT_H": 0,
    "HAVE_DIRENT_D_TYPE": 1,
    "HAVE_DIRENT_H": 1,
    "HAVE_DIRFD": 1,
    "HAVE_DLADDR": 1,
    "HAVE_DLFCN_H": 1,
    "HAVE_DLOPEN": 1,
    "HAVE_DUP": 1,
    "HAVE_DUP2": 1,
    "HAVE_DUP3": 1,
    "HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH": 0,
    "HAVE_DYNAMIC_LOADING": 1,
    "HAVE_EDITLINE_READLINE_H": 0,
    "HAVE_ENDIAN_H": 1,
    "HAVE_EPOLL": 1,
    "HAVE_EPOLL_CREATE1": 1,
    "HAVE_ERF": 1,
    "HAVE_ERFC": 1,
    "HAVE_ERRNO_H": 1,
    "HAVE_EVENTFD": 1,
    "HAVE_EXECV": 1,
    "HAVE_EXPLICIT_BZERO": 0,
    "HAVE_EXPLICIT_MEMSET": 0,
    "HAVE_EXPM1": 1,
    "HAVE_FACCESSAT": 1,
    "HAVE_FCHDIR": 1,
    "HAVE_FCHMOD": 1,
    "HAVE_FCHMODAT": 1,
    "HAVE_FCHOWN": 1,
    "HAVE_FCHOWNAT": 1,
    "HAVE_FCNTL_H": 1,
    "HAVE_FDATASYNC": 1,
    "HAVE_FDOPENDIR": 1,
    "HAVE_FDWALK": 0,
    "HAVE_FEXECVE": 1,
    "HAVE_FFI_CLOSURE_ALLOC": 1,
    "HAVE_FFI_PREP_CIF_VAR": 1,
    "HAVE_FFI_PREP_CLOSURE_LOC": 1,
    "HAVE_FLOCK": 1,
    "HAVE_FORK": 1,
    "HAVE_FORK1": 0,
    "HAVE_FORKPTY": 1,
    "HAVE_FPATHCONF": 1,
    "HAVE_FSEEK64": 0,
    "HAVE_FSEEKO": 1,
    "HAVE_FSTATAT": 1,
    "HAVE_FSTATVFS": 1,
    "HAVE_FSYNC": 1,
    "HAVE_FTELL64": 0,
    "HAVE_FTELLO": 1,
    "HAVE_FTIME": 1,
    "HAVE_FTRUNCATE": 1,
    "HAVE_FUTIMENS": 1,
    "HAVE_FUTIMES": 1,
    "HAVE_FUTIMESAT": 1,
    "HAVE_GAI_STRERROR": 1,
    "HAVE_GCC_ASM_FOR_MC68881": 0,
    "HAVE_GCC_ASM_FOR_X64": 1,
    "HAVE_GCC_ASM_FOR_X87": 1,
    "HAVE_GCC_UINT128_T": 1,
    "HAVE_GDBM_DASH_NDBM_H": 0,
    "HAVE_GDBM_H": 0,
    "HAVE_GDBM_NDBM_H": 0,
    "HAVE_GETADDRINFO": 1,
    "HAVE_GETC_UNLOCKED": 1,
    "HAVE_GETEGID": 1,
    "HAVE_GETENTROPY": 0,
    "HAVE_GETEUID": 1,
    "HAVE_GETGID": 1,
    "HAVE_GETGRENT": 1,
    "HAVE_GETGRGID": 1,
    "HAVE_GETGRGID_R": 1,
    "HAVE_GETGRNAM_R": 1,
    "HAVE_GETGROUPLIST": 1,
    "HAVE_GETGROUPS": 1,
    "HAVE_GETHOSTBYADDR": 1,
    "HAVE_GETHOSTBYNAME": 1,
    "HAVE_GETHOSTBYNAME_R": 1,
    "HAVE_GETHOSTBYNAME_R_3_ARG": 0,
    "HAVE_GETHOSTBYNAME_R_5_ARG": 0,
    "HAVE_GETHOSTBYNAME_R_6_ARG": 1,
    "HAVE_GETHOSTNAME": 1,
    "HAVE_GETITIMER": 1,
    "HAVE_GETLOADAVG": 1,
    "HAVE_GETLOGIN": 1,
    "HAVE_GETLOGIN_R": 1,
    "HAVE_GETNAMEINFO": 1,
    "HAVE_GETPAGESIZE": 1,
    "HAVE_GETPEERNAME": 1,
    "HAVE_GETPGID": 1,
    "HAVE_GETPGRP": 1,
    "HAVE_GETPID": 1,
    "HAVE_GETPPID": 1,
    "HAVE_GETPRIORITY": 1,
    "HAVE_GETPROTOBYNAME": 1,
    "HAVE_GETPWENT": 1,
    "HAVE_GETPWNAM_R": 1,
    "HAVE_GETPWUID": 1,
    "HAVE_GETPWUID_R": 1,
    "HAVE_GETRANDOM": 0,
    "HAVE_GETRANDOM_SYSCALL": 0,
    "HAVE_GETRESGID": 1,
    "HAVE_GETRESUID": 1,
    "HAVE_GETRUSAGE": 1,
    "HAVE_GETSERVBYNAME": 1,
    "HAVE_GETSERVBYPORT": 1,
    "HAVE_GETSID": 1,
    "HAVE_GETSOCKNAME": 1,
    "HAVE_GETSPENT": 1,
    "HAVE_GETSPNAM": 1,
    "HAVE_GETUID": 1,
    "HAVE_GETWD": 1,
    "HAVE_GLIBC_MEMMOVE_BUG": 0,
    "HAVE_GRANTPT": 1,
    "HAVE_GRP_H": 1,
    "HAVE_HSTRERROR": 1,
    "HAVE_HTOLE64": 1,
    "HAVE_IF_NAMEINDEX": 1,
    "HAVE_INET_ATON": 1,
    "HAVE_INET_NTOA": 1,
    "HAVE_INET_PTON": 1,
    "HAVE_INITGROUPS": 1,
    "HAVE_INTTYPES_H": 1,
    "HAVE_IO_H": 0,
    "HAVE_IPA_PURE_CONST_BUG": 0,
    "HAVE_KILL": 1,
    "HAVE_KILLPG": 1,
    "HAVE_KQUEUE": 0,
    "HAVE_LANGINFO_H": 1,
    "HAVE_LARGEFILE_SUPPORT": 0,
    "HAVE_LCHFLAGS": 0,
    "HAVE_LCHMOD": 0,
    "HAVE_LCHOWN": 1,
    "HAVE_LIBB2": 0,
    "HAVE_LIBDB": 1,
    "HAVE_LIBDL": 1,
    "HAVE_LIBDLD": 0,
    "HAVE_LIBIEEE": 0,
    "HAVE_LIBINTL_H": 1,
    "HAVE_LIBRESOLV": 0,
    "HAVE_LIBSENDFILE": 0,
    "HAVE_LIBSQLITE3": 1,
    "HAVE_LIBUTIL_H": 0,
    "HAVE_LINK": 1,
    "HAVE_LINKAT": 1,
    "HAVE_LINUX_AUXVEC_H": 1,
    "HAVE_LINUX_CAN_BCM_H": 1,
    "HAVE_LINUX_CAN_H": 1,
    "HAVE_LINUX_CAN_J1939_H": 0,
    "HAVE_LINUX_CAN_RAW_FD_FRAMES": 1,
    "HAVE_LINUX_CAN_RAW_H": 1,
    "HAVE_LINUX_CAN_RAW_JOIN_FILTERS": 0,
    "HAVE_LINUX_FS_H": 1,
    "HAVE_LINUX_LIMITS_H": 1,
    "HAVE_LINUX_MEMFD_H": 1,
    "HAVE_LINUX_NETLINK_H": 1,
    "HAVE_LINUX_QRTR_H": 0,
    "HAVE_LINUX_RANDOM_H": 1,
    "HAVE_LINUX_SOUNDCARD_H": 1,
    "HAVE_LINUX_TIPC_H": 1,
    "HAVE_LINUX_VM_SOCKETS_H": 1,
    "HAVE_LINUX_WAIT_H": 1,
    "HAVE_LISTEN": 1,
    "HAVE_LOCKF": 1,
    "HAVE_LOG1P": 1,
    "HAVE_LOG2": 1,
    "HAVE_LOGIN_TTY": 1,
    "HAVE_LONG_DOUBLE": 1,
    "HAVE_LSTAT": 1,
    "HAVE_LUTIMES": 1,
    "HAVE_LZMA_H": 0,
    "HAVE_MADVISE": 1,
    "HAVE_MAKEDEV": 1,
    "HAVE_MAXLOGNAME": 0,
    "HAVE_MBRTOWC": 1,
    "HAVE_MEMFD_CREATE": 0,
    "HAVE_MEMRCHR": 1,
    "HAVE_MINIX_CONFIG_H": 0,
    "HAVE_MKDIRAT": 1,
    "HAVE_MKFIFO": 1,
    "HAVE_MKFIFOAT": 1,
    "HAVE_MKNOD": 1,
    "HAVE_MKNODAT": 1,
    "HAVE_MKTIME": 1,
    "HAVE_MMAP": 1,
    "HAVE_MREMAP": 1,
    "HAVE_NANOSLEEP": 1,
    "HAVE_NCURSES": 0,
    "HAVE_NCURSESW": 0,
    "HAVE_NCURSESW_CURSES_H": 1,
    "HAVE_NCURSESW_NCURSES_H": 1,
    "HAVE_NCURSESW_PANEL_H": 1,
    "HAVE_NCURSES_CURSES_H": 0,
    "HAVE_NCURSES_H": 1,
    "HAVE_NCURSES_NCURSES_H": 0,
    "HAVE_NCURSES_PANEL_H": 0,
    "HAVE_NDBM_H": 0,
    "HAVE_NDIR_H": 0,
    "HAVE_NETCAN_CAN_H": 0,
    "HAVE_NETDB_H": 1,
    "HAVE_NETINET_IN_H": 1,
    "HAVE_NETLINK_NETLINK_H": 0,
    "HAVE_NETPACKET_PACKET_H": 1,
    "HAVE_NET_ETHERNET_H": 1,
    "HAVE_NET_IF_H": 1,
    "HAVE_NICE": 1,
    "HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION": 0,
    "HAVE_OPENAT": 1,
    "HAVE_OPENDIR": 1,
    "HAVE_OPENPTY": 1,
    "HAVE_PANEL": 0,
    "HAVE_PANELW": 0,
    "HAVE_PANEL_H": 1,
    "HAVE_PATHCONF": 1,
    "HAVE_PAUSE": 1,
    "HAVE_PIPE": 1,
    "HAVE_PIPE2": 1,
    "HAVE_PLOCK": 0,
    "HAVE_POLL": 1,
    "HAVE_POLL_H": 1,
    "HAVE_POSIX_FADVISE": 1,
    "HAVE_POSIX_FALLOCATE": 1,
    "HAVE_POSIX_OPENPT": 1,
    "HAVE_POSIX_SPAWN": 1,
    "HAVE_POSIX_SPAWNP": 1,
    "HAVE_POSIX_SPAWN_FILE_ACTIONS_ADDCLOSEFROM_NP": 0,
    "HAVE_PREAD": 1,
    "HAVE_PREADV": 1,
    "HAVE_PREADV2": 0,
    "HAVE_PRLIMIT": 1,
    "HAVE_PROCESS_H": 0,
    "HAVE_PROCESS_VM_READV": 1,
    "HAVE_PROTOTYPES": 1,
    "HAVE_PTHREAD_CONDATTR_SETCLOCK": 1,
    "HAVE_PTHREAD_COND_TIMEDWAIT_RELATIVE_NP": 0,
    "HAVE_PTHREAD_DESTRUCTOR": 0,
    "HAVE_PTHREAD_GETCPUCLOCKID": 1,
    "HAVE_PTHREAD_H": 1,
    "HAVE_PTHREAD_INIT": 0,
    "HAVE_PTHREAD_KILL": 1,
    "HAVE_PTHREAD_SIGMASK": 1,
    "HAVE_PTHREAD_STUBS": 0,
    "HAVE_PTSNAME": 1,
    "HAVE_PTSNAME_R": 1,
    "HAVE_PTY_H": 1,
    "HAVE_PWRITE": 1,
    "HAVE_PWRITEV": 1,
    "HAVE_PWRITEV2": 0,
    "HAVE_READLINE_READLINE_H": 0,
    "HAVE_READLINK": 1,
    "HAVE_READLINKAT": 1,
    "HAVE_READV": 1,
    "HAVE_REALPATH": 1,
    "HAVE_RECVFROM": 1,
    "HAVE_RENAMEAT": 1,
    "HAVE_RL_APPEND_HISTORY": 1,
    "HAVE_RL_CATCH_SIGNAL": 1,
    "HAVE_RL_COMPDISP_FUNC_T": 1,
    "HAVE_RL_COMPLETION_APPEND_CHARACTER": 1,
    "HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK": 1,
    "HAVE_RL_COMPLETION_MATCHES": 1,
    "HAVE_RL_COMPLETION_SUPPRESS_APPEND": 1,
    "HAVE_RL_PRE_INPUT_HOOK": 1,
    "HAVE_RL_RESIZE_TERMINAL": 1,
    "HAVE_RTPSPAWN": 0,
    "HAVE_SCHED_GET_PRIORITY_MAX": 1,
    "HAVE_SCHED_H": 1,
    "HAVE_SCHED_RR_GET_INTERVAL": 1,
    "HAVE_SCHED_SETAFFINITY": 1,
    "HAVE_SCHED_SETPARAM": 1,
    "HAVE_SCHED_SETSCHEDULER": 1,
    "HAVE_SEM_CLOCKWAIT": 0,
    "HAVE_SEM_GETVALUE": 1,
    "HAVE_SEM_OPEN": 1,
    "HAVE_SEM_TIMEDWAIT": 1,
    "HAVE_SEM_UNLINK": 1,
    "HAVE_SENDFILE": 1,
    "HAVE_SENDTO": 1,
    "HAVE_SETEGID": 1,
    "HAVE_SETEUID": 1,
    "HAVE_SETGID": 1,
    "HAVE_SETGROUPS": 1,
    "HAVE_SETHOSTNAME": 1,
    "HAVE_SETITIMER": 1,
    "HAVE_SETJMP_H": 1,
    "HAVE_SETLOCALE": 1,
    "HAVE_SETNS": 1,
    "HAVE_SETPGID": 1,
    "HAVE_SETPGRP": 1,
    "HAVE_SETPRIORITY": 1,
    "HAVE_SETREGID": 1,
    "HAVE_SETRESGID": 1,
    "HAVE_SETRESUID": 1,
    "HAVE_SETREUID": 1,
    "HAVE_SETSID": 1,
    "HAVE_SETSOCKOPT": 1,
    "HAVE_SETUID": 1,
    "HAVE_SETVBUF": 1,
    "HAVE_SHADOW_H": 1,
    "HAVE_SHM_OPEN": 1,
    "HAVE_SHM_UNLINK": 1,
    "HAVE_SHUTDOWN": 1,
    "HAVE_SIGACTION": 1,
    "HAVE_SIGALTSTACK": 1,
    "HAVE_SIGFILLSET": 1,
    "HAVE_SIGINFO_T_SI_BAND": 1,
    "HAVE_SIGINTERRUPT": 1,
    "HAVE_SIGNAL_H": 1,
    "HAVE_SIGPENDING": 1,
    "HAVE_SIGRELSE": 1,
    "HAVE_SIGTIMEDWAIT": 1,
    "HAVE_SIGWAIT": 1,
    "HAVE_SIGWAITINFO": 1,
    "HAVE_SNPRINTF": 1,
    "HAVE_SOCKADDR_ALG": 1,
    "HAVE_SOCKADDR_SA_LEN": 0,
    "HAVE_SOCKADDR_STORAGE": 1,
    "HAVE_SOCKET": 1,
    "HAVE_SOCKETPAIR": 1,
    "HAVE_SOCKLEN_T": 1,
    "HAVE_SPAWN_H": 1,
    "HAVE_SPLICE": 1,
    "HAVE_SSIZE_T": 1,
    "HAVE_STATVFS": 1,
    "HAVE_STAT_TV_NSEC": 1,
    "HAVE_STAT_TV_NSEC2": 0,
    "HAVE_STDINT_H": 1,
    "HAVE_STDIO_H": 1,
    "HAVE_STDLIB_H": 1,
    "HAVE_STD_ATOMIC": 1,
    "HAVE_STRFTIME": 1,
    "HAVE_STRINGS_H": 1,
    "HAVE_STRING_H": 1,
    "HAVE_STRLCPY": 0,
    "HAVE_STROPTS_H": 1,
    "HAVE_STRSIGNAL": 1,
    "HAVE_STRUCT_PASSWD_PW_GECOS": 1,
    "HAVE_STRUCT_PASSWD_PW_PASSWD": 1,
    "HAVE_STRUCT_STAT_ST_BIRTHTIME": 0,
    "HAVE_STRUCT_STAT_ST_BLKSIZE": 1,
    "HAVE_STRUCT_STAT_ST_BLOCKS": 1,
    "HAVE_STRUCT_STAT_ST_FLAGS": 0,
    "HAVE_STRUCT_STAT_ST_GEN": 0,
    "HAVE_STRUCT_STAT_ST_RDEV": 1,
    "HAVE_STRUCT_TM_TM_ZONE": 1,
    "HAVE_SYMLINK": 1,
    "HAVE_SYMLINKAT": 1,
    "HAVE_SYNC": 1,
    "HAVE_SYSCONF": 1,
    "HAVE_SYSEXITS_H": 1,
    "HAVE_SYSLOG_H": 1,
    "HAVE_SYSTEM": 1,
    "HAVE_SYS_AUDIOIO_H": 0,
    "HAVE_SYS_AUXV_H": 1,
    "HAVE_SYS_BSDTTY_H": 0,
    "HAVE_SYS_DEVPOLL_H": 0,
    "HAVE_SYS_DIR_H": 0,
    "HAVE_SYS_ENDIAN_H": 0,
    "HAVE_SYS_EPOLL_H": 1,
    "HAVE_SYS_EVENTFD_H": 1,
    "HAVE_SYS_EVENT_H": 0,
    "HAVE_SYS_FILE_H": 1,
    "HAVE_SYS_IOCTL_H": 1,
    "HAVE_SYS_KERN_CONTROL_H": 0,
    "HAVE_SYS_LOADAVG_H": 0,
    "HAVE_SYS_LOCK_H": 0,
    "HAVE_SYS_MEMFD_H": 0,
    "HAVE_SYS_MKDEV_H": 0,
    "HAVE_SYS_MMAN_H": 1,
    "HAVE_SYS_MODEM_H": 0,
    "HAVE_SYS_NDIR_H": 0,
    "HAVE_SYS_PARAM_H": 1,
    "HAVE_SYS_PIDFD_H": 0,
    "HAVE_SYS_POLL_H": 1,
    "HAVE_SYS_RANDOM_H": 0,
    "HAVE_SYS_RESOURCE_H": 1,
    "HAVE_SYS_SELECT_H": 1,
    "HAVE_SYS_SENDFILE_H": 1,
    "HAVE_SYS_SOCKET_H": 1,
    "HAVE_SYS_SOUNDCARD_H": 1,
    "HAVE_SYS_STATVFS_H": 1,
    "HAVE_SYS_STAT_H": 1,
    "HAVE_SYS_SYSCALL_H": 1,
    "HAVE_SYS_SYSMACROS_H": 1,
    "HAVE_SYS_SYS_DOMAIN_H": 0,
    "HAVE_SYS_TERMIO_H": 0,
    "HAVE_SYS_TIMERFD_H": 1,
    "HAVE_SYS_TIMES_H": 1,
    "HAVE_SYS_TIME_H": 1,
    "HAVE_SYS_TYPES_H": 1,
    "HAVE_SYS_UIO_H": 1,
    "HAVE_SYS_UN_H": 1,
    "HAVE_SYS_UTSNAME_H": 1,
    "HAVE_SYS_WAIT_H": 1,
    "HAVE_SYS_XATTR_H": 1,
    "HAVE_TCGETPGRP": 1,
    "HAVE_TCSETPGRP": 1,
    "HAVE_TEMPNAM": 1,
    "HAVE_TERMIOS_H": 1,
    "HAVE_TERM_H": 1,
    "HAVE_TIMEGM": 1,
    "HAVE_TIMERFD_CREATE": 1,
    "HAVE_TIMES": 1,
    "HAVE_TMPFILE": 1,
    "HAVE_TMPNAM": 1,
    "HAVE_TMPNAM_R": 1,
    "HAVE_TM_ZONE": 1,
    "HAVE_TRUNCATE": 1,
    "HAVE_TTYNAME_R": 1,
    "HAVE_TZNAME": 0,
    "HAVE_UMASK": 1,
    "HAVE_UNAME": 1,
    "HAVE_UNISTD_H": 1,
    "HAVE_UNLINKAT": 1,
    "HAVE_UNLOCKPT": 1,
    "HAVE_UNSHARE": 1,
    "HAVE_USABLE_WCHAR_T": 0,
    "HAVE_UTIL_H": 0,
    "HAVE_UTIMENSAT": 1,
    "HAVE_UTIMES": 1,
    "HAVE_UTIME_H": 1,
    "HAVE_UTMP_H": 1,
    "HAVE_UT_NAMESIZE": 1,
    "HAVE_UUID_CREATE": 0,
    "HAVE_UUID_ENC_BE": 0,
    "HAVE_UUID_GENERATE_TIME_SAFE": 1,
    "HAVE_UUID_GENERATE_TIME_SAFE_STABLE_MAC": 0,
    "HAVE_UUID_H": 0,
    "HAVE_UUID_UUID_H": 1,
    "HAVE_VFORK": 1,
    "HAVE_WAIT": 1,
    "HAVE_WAIT3": 1,
    "HAVE_WAIT4": 1,
    "HAVE_WAITID": 1,
    "HAVE_WAITPID": 1,
    "HAVE_WCHAR_H": 1,
    "HAVE_WCSCOLL": 1,
    "HAVE_WCSFTIME": 1,
    "HAVE_WCSXFRM": 1,
    "HAVE_WMEMCMP": 1,
    "HAVE_WORKING_TZSET": 1,
    "HAVE_WRITEV": 1,
    "HAVE_ZLIB_COPY": 1,
    "HAVE_ZLIB_H": 0,
    "HAVE__GETPTY": 0,
    "HAVE___UINT128_T": 1,
    "HOSTRUNNER": "",
    "HOST_GNU_TYPE": "x86_64-unknown-linux-gnu",
    "INCLDIRSTOMAKE": "/install/include /install/include /install/include/python3.13 /install/include/python3.13",
    "INCLUDEDIR": "/install/include",
    "INCLUDEPY": "/install/include/python3.13",
    "INSTALL": "/usr/bin/install -c",
    "INSTALL_DATA": "/usr/bin/install -c -m 644",
    "INSTALL_MIMALLOC": "yes",
    "INSTALL_PROGRAM": "/usr/bin/install -c",
    "INSTALL_SCRIPT": "/usr/bin/install -c",
    "INSTALL_SHARED": "/usr/bin/install -c -m 755",
    "INSTSONAME": "libpython3.13.so.1.0",
    "IO_H": "Modules/_io/_iomodule.h",
    "IO_OBJS": "\\",
    "IPHONEOS_DEPLOYMENT_TARGET": "",
    "JIT_DEPS": "\\",
    "LDCXXSHARED": "clang++ -pthread -shared -Wl,-z,noexecstack  -Wl,--exclude-libs,ALL ",
    "LDFLAGS": "-Wl,-z,noexecstack  -Wl,--exclude-libs,ALL ",
    "LDLIBRARY": "libpython3.13.so",
    "LDLIBRARYDIR": "",
    "LDSHARED": "clang -pthread -shared -Wl,-z,noexecstack  -Wl,--exclude-libs,ALL ",
    "LDVERSION": "3.13",
    "LIBC": "",
    "LIBDEST": "/install/lib/python3.13",
    "LIBDIR": "/install/lib",
    "LIBEXPAT_A": "Modules/expat/libexpat.a",
    "LIBEXPAT_CFLAGS": "-fno-strict-overflow -Wsign-compare -Wunreachable-code -DNDEBUG -g -O3 -Wall -O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC   -D_Py_TIER2=3 -D_Py_JIT -flto=thin -g -fno-pie -std=c11 -Wextra -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=/build/Python-3.13.14/code.profclangd -I./Include/internal -I./Include/internal/mimalloc -I. -I./Include -O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC   -fPIC -fPIC",
    "LIBEXPAT_HEADERS": "\\",
    "LIBEXPAT_OBJS": "\\",
    "LIBHACL_CFLAGS": "-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE -fno-strict-overflow -Wsign-compare -Wunreachable-code -DNDEBUG -g -O3 -Wall -O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC   -D_Py_TIER2=3 -D_Py_JIT -flto=thin -g -fno-pie -std=c11 -Wextra -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=/build/Python-3.13.14/code.profclangd -I./Include/internal -I./Include/internal/mimalloc -I. -I./Include -O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC   -fPIC -fPIC",
    "LIBHACL_HEADERS": "\\",
    "LIBHACL_SHA2_A": "Modules/_hacl/libHacl_Hash_SHA2.a",
    "LIBHACL_SHA2_HEADERS": "\\",
    "LIBHACL_SHA2_OBJS": "\\",
    "LIBM": "-lm",
    "LIBMPDEC_A": "Modules/_decimal/libmpdec/libmpdec.a",
    "LIBMPDEC_CFLAGS": "  -fno-strict-overflow -Wsign-compare -Wunreachable-code -DNDEBUG -g -O3 -Wall -O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC   -D_Py_TIER2=3 -D_Py_JIT -flto=thin -g -fno-pie -std=c11 -Wextra -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=/build/Python-3.13.14/code.profclangd -I./Include/internal -I./Include/internal/mimalloc -I. -I./Include -O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC   -fPIC -fPIC",
    "LIBMPDEC_HEADERS": "\\",
    "LIBMPDEC_OBJS": "\\",
    "LIBOBJDIR": "Python/",
    "LIBOBJS": "",
    "LIBPC": "/install/lib/pkgconfig",
    "LIBPL": "/install/lib/python3.13/config-3.13-x86_64-linux-gnu",
    "LIBPYTHON": "",
    "LIBRARY": "libpython3.13.a",
    "LIBRARY_DEPS": "libpython3.13.a libpython3.13.so libpython3.so",
    "LIBRARY_OBJS": "\\",
    "LIBRARY_OBJS_OMIT_FROZEN": "\\",
    "LIBS": "-lpthread -ldl  -lutil",
    "LIBSUBDIRS": "asyncio \\",
    "LINKCC": "clang -pthread -fno-pie -no-pie",
    "LINKFORSHARED": "-Xlinker -export-dynamic",
    "LINK_PYTHON_DEPS": "libpython3.13.a libpython3.13.so libpython3.so",
    "LINK_PYTHON_OBJS": "\\",
    "LIPO_32BIT_FLAGS": "",
    "LIPO_INTEL64_FLAGS": "",
    "LLVM_MERGED_DATA_FILE": "$(shell pwd)/code.profclangd",
    "LLVM_PROFDATA": "/tools/llvm/bin/llvm-profdata",
    "LLVM_PROF_ERR": "no",
    "LLVM_PROF_FILE": "LLVM_PROFILE_FILE=\"$(shell pwd)/code-%128m.profclangr\"",
    "LLVM_PROF_MERGER": "/tools/llvm/bin/llvm-profdata merge -output=\"$(shell pwd)/code.profclangd\" \"$(shell pwd)\"/*.profclangr",
    "LN": "ln",
    "LOCALMODLIBS": "-lbz2          -lffi -ldl  -lncursesw  -lpanelw -lncursesw   -lmpdec  -lexpat  -lcrypto -l:libatomic.a        -llzma       -lrt         -lsqlite3  -lssl -lcrypto -l:libatomic.a        -luuid      -lm    -lm   -lexpat  -ledit -lncursesw        -lz",
    "MACHDEP": "linux",
    "MACHDEP_OBJS": "",
    "MACHDESTLIB": "/install/lib/python3.13",
    "MACOSX_DEPLOYMENT_TARGET": "",
    "MAJOR_IN_MKDEV": 0,
    "MAJOR_IN_SYSMACROS": 1,
    "MAKESETUP": "./Modules/makesetup",
    "MANDIR": "/install/share/man",
    "MIMALLOC_HEADERS": "\\",
    "MKDIR_P": "/bin/mkdir -p",
    "MODBUILT_NAMES": "_ctypes_test  _dbm  _testbuffer  _testcapi  _testexternalinspection  _testimportmultiple  _testlimitedcapi  _testmultiphase  _testsinglephase  _tkinter  _asyncio  _bisect  _blake2  _bz2  _codecs_cn  _codecs_hk  _codecs_iso2022  _codecs_jp  _codecs_kr  _codecs_tw  _contextvars  _csv  _ctypes  _curses  _curses_panel  _datetime  _decimal  _elementtree  _hashlib  _heapq  _interpchannels  _interpqueues  _interpreters  _json  _lsprof  _lzma  _md5  _multibytecodec  _multiprocessing  _opcode  _pickle  _posixshmem  _posixsubprocess  _queue  _random  _sha1  _sha2  _sha3  _socket  _sqlite3  _ssl  _statistics  _struct  _suggestions  _sysconfig  _testinternalcapi  _typing  _uuid  _xxtestfuzz  _zoneinfo  array  binascii  cmath  fcntl  grp  math  mmap  pyexpat  readline  resource  select  syslog  termios  unicodedata  xxsubtype  zlib  atexit  faulthandler  posix  _signal  _tracemalloc  _codecs  _collections  errno  _io  itertools  _sre  _thread  time  _weakref  _abc  _functools  _locale  _operator  _stat  _symtable  pwd",
    "MODDISABLED_NAMES": "_gdbm  _scproxy  xx  xxlimited  xxlimited_35",
    "MODLIBS": "-lbz2          -lffi -ldl  -lncursesw  -lpanelw -lncursesw   -lmpdec  -lexpat  -lcrypto -l:libatomic.a        -llzma       -lrt         -lsqlite3  -lssl -lcrypto -l:libatomic.a        -luuid      -lm    -lm   -lexpat  -ledit -lncursesw        -lz",
    "MODOBJS": "Modules/_asynciomodule.o  Modules/_bisectmodule.o  Modules/_blake2/blake2module.o Modules/_blake2/blake2b_impl.o Modules/_blake2/blake2s_impl.o  Modules/_bz2module.o  Modules/cjkcodecs/_codecs_cn.o  Modules/cjkcodecs/_codecs_hk.o  Modules/cjkcodecs/_codecs_iso2022.o  Modules/cjkcodecs/_codecs_jp.o  Modules/cjkcodecs/_codecs_kr.o  Modules/cjkcodecs/_codecs_tw.o  Modules/_contextvarsmodule.o  Modules/_csv.o  Modules/_ctypes/_ctypes.o Modules/_ctypes/callbacks.o Modules/_ctypes/callproc.o Modules/_ctypes/stgdict.o Modules/_ctypes/cfield.o  Modules/_cursesmodule.o  Modules/_curses_panel.o  Modules/_datetimemodule.o  Modules/_decimal/_decimal.o  Modules/_elementtree.o  Modules/_hashopenssl.o  Modules/_heapqmodule.o  Modules/_interpchannelsmodule.o  Modules/_interpqueuesmodule.o  Modules/_interpretersmodule.o  Modules/_json.o  Modules/_lsprof.o Modules/rotatingtree.o  Modules/_lzmamodule.o  Modules/md5module.o Modules/_hacl/Hacl_Hash_MD5.o  Modules/cjkcodecs/multibytecodec.o  Modules/_multiprocessing/multiprocessing.o Modules/_multiprocessing/semaphore.o  Modules/_opcode.o  Modules/_pickle.o  Modules/_multiprocessing/posixshmem.o  Modules/_posixsubprocess.o  Modules/_queuemodule.o  Modules/_randommodule.o  Modules/sha1module.o Modules/_hacl/Hacl_Hash_SHA1.o  Modules/sha2module.o Modules/_hacl/Hacl_Hash_SHA2.o  Modules/sha3module.o Modules/_hacl/Hacl_Hash_SHA3.o  Modules/socketmodule.o  Modules/_sqlite/connection.o Modules/_sqlite/cursor.o Modules/_sqlite/microprotocols.o Modules/_sqlite/module.o Modules/_sqlite/prepare_protocol.o Modules/_sqlite/row.o Modules/_sqlite/statement.o Modules/_sqlite/util.o Modules/_sqlite/blob.o  Modules/_ssl.o  Modules/_statisticsmodule.o  Modules/_struct.o  Modules/_suggestions.o  Modules/_sysconfig.o  Modules/_testinternalcapi.o Modules/_testinternalcapi/pytime.o Modules/_testinternalcapi/set.o Modules/_testinternalcapi/test_critical_sections.o Modules/_testinternalcapi/test_lock.o  Modules/_typingmodule.o  Modules/_uuidmodule.o  Modules/_xxtestfuzz/_xxtestfuzz.o Modules/_xxtestfuzz/fuzzer.o  Modules/_zoneinfo.o  Modules/arraymodule.o  Modules/binascii.o  Modules/cmathmodule.o  Modules/fcntlmodule.o  Modules/grpmodule.o  Modules/mathmodule.o  Modules/mmapmodule.o  Modules/pyexpat.o  Modules/readline.o  Modules/resource.o  Modules/selectmodule.o  Modules/syslogmodule.o  Modules/termios.o  Modules/unicodedata.o  Modules/xxsubtype.o  Modules/zlibmodule.o  Modules/atexitmodule.o  Modules/faulthandler.o  Modules/posixmodule.o  Modules/signalmodule.o  Modules/_tracemalloc.o  Modules/_codecsmodule.o  Modules/_collectionsmodule.o  Modules/errnomodule.o  Modules/_io/_iomodule.o Modules/_io/iobase.o Modules/_io/fileio.o Modules/_io/bytesio.o Modules/_io/bufferedio.o Modules/_io/textio.o Modules/_io/stringio.o  Modules/itertoolsmodule.o  Modules/_sre/sre.o  Modules/_threadmodule.o  Modules/timemodule.o  Modules/_weakref.o  Modules/_abc.o  Modules/_functoolsmodule.o  Modules/_localemodule.o  Modules/_operator.o  Modules/_stat.o  Modules/symtablemodule.o  Modules/pwdmodule.o",
    "MODSHARED_NAMES": "_ctypes_test _dbm _testbuffer _testcapi _testexternalinspection _testimportmultiple _testlimitedcapi _testmultiphase _testsinglephase _tkinter",
    "MODULE_ARRAY_LDFLAGS": "",
    "MODULE_ARRAY_STATE": "disabled",
    "MODULE_ATEXIT_LDFLAGS": "",
    "MODULE_BINASCII_LDFLAGS": "",
    "MODULE_BINASCII_STATE": "disabled",
    "MODULE_CMATH_DEPS": "./Modules/_math.h",
    "MODULE_CMATH_STATE": "disabled",
    "MODULE_DEPS_SHARED": "Modules/config.c",
    "MODULE_DEPS_STATIC": "Modules/config.c",
    "MODULE_ERRNO_LDFLAGS": "",
    "MODULE_FAULTHANDLER_LDFLAGS": "",
    "MODULE_FCNTL_LDFLAGS": "",
    "MODULE_FCNTL_STATE": "disabled",
    "MODULE_GRP_LDFLAGS": "",
    "MODULE_GRP_STATE": "disabled",
    "MODULE_ITERTOOLS_LDFLAGS": "",
    "MODULE_MATH_DEPS": "./Modules/_math.h",
    "MODULE_MATH_STATE": "disabled",
    "MODULE_MMAP_LDFLAGS": "",
    "MODULE_MMAP_STATE": "disabled",
    "MODULE_OBJS": "\\",
    "MODULE_POSIX_LDFLAGS": "",
    "MODULE_PWD_LDFLAGS": "",
    "MODULE_PWD_STATE": "disabled",
    "MODULE_PYEXPAT_DEPS": "",
    "MODULE_PYEXPAT_STATE": "disabled",
    "MODULE_READLINE_STATE": "disabled",
    "MODULE_RESOURCE_LDFLAGS": "",
    "MODULE_RESOURCE_STATE": "disabled",
    "MODULE_SELECT_LDFLAGS": "",
    "MODULE_SELECT_STATE": "disabled",
    "MODULE_SYSLOG_LDFLAGS": "",
    "MODULE_SYSLOG_STATE": "disabled",
    "MODULE_TERMIOS_LDFLAGS": "",
    "MODULE_TERMIOS_STATE": "disabled",
    "MODULE_TIME_LDFLAGS": "",
    "MODULE_TIME_STATE": "disabled",
    "MODULE_UNICODEDATA_DEPS": "./Modules/unicodedata_db.h ./Modules/unicodename_db.h",
    "MODULE_UNICODEDATA_LDFLAGS": "",
    "MODULE_UNICODEDATA_STATE": "disabled",
    "MODULE_XXLIMITED_35_STATE": "disabled",
    "MODULE_XXLIMITED_STATE": "disabled",
    "MODULE_XXSUBTYPE_LDFLAGS": "",
    "MODULE_XXSUBTYPE_STATE": "disabled",
    "MODULE_ZLIB_STATE": "disabled",
    "MODULE__ABC_LDFLAGS": "",
    "MODULE__ASYNCIO_LDFLAGS": "",
    "MODULE__ASYNCIO_STATE": "disabled",
    "MODULE__BISECT_LDFLAGS": "",
    "MODULE__BISECT_STATE": "disabled",
    "MODULE__BLAKE2_DEPS": "./Modules/_blake2/impl/blake2-config.h ./Modules/_blake2/impl/blake2-impl.h ./Modules/_blake2/impl/blake2.h ./Modules/_blake2/impl/blake2b-load-sse2.h ./Modules/_blake2/impl/blake2b-load-sse41.h ./Modules/_blake2/impl/blake2b-ref.c ./Modules/_blake2/impl/blake2b-round.h ./Modules/_blake2/impl/blake2b.c ./Modules/_blake2/impl/blake2s-load-sse2.h ./Modules/_blake2/impl/blake2s-load-sse41.h ./Modules/_blake2/impl/blake2s-load-xop.h ./Modules/_blake2/impl/blake2s-ref.c ./Modules/_blake2/impl/blake2s-round.h ./Modules/_blake2/impl/blake2s.c ./Modules/_blake2/blake2module.h ./Modules/hashlib.h",
    "MODULE__BLAKE2_LDFLAGS": "",
    "MODULE__BLAKE2_STATE": "disabled",
    "MODULE__BZ2_STATE": "disabled",
    "MODULE__CODECS_CN_DEPS": "./Modules/cjkcodecs/mappings_cn.h ./Modules/cjkcodecs/multibytecodec.h ./Modules/cjkcodecs/cjkcodecs.h",
    "MODULE__CODECS_CN_LDFLAGS": "",
    "MODULE__CODECS_CN_STATE": "disabled",
    "MODULE__CODECS_HK_DEPS": "./Modules/cjkcodecs/mappings_hk.h  ./Modules/cjkcodecs/multibytecodec.h ./Modules/cjkcodecs/cjkcodecs.h",
    "MODULE__CODECS_HK_LDFLAGS": "",
    "MODULE__CODECS_HK_STATE": "disabled",
    "MODULE__CODECS_ISO2022_DEPS": "./Modules/cjkcodecs/mappings_jisx0213_pair.h ./Modules/cjkcodecs/alg_jisx0201.h ./Modules/cjkcodecs/emu_jisx0213_2000.h ./Modules/cjkcodecs/multibytecodec.h ./Modules/cjkcodecs/cjkcodecs.h",
    "MODULE__CODECS_ISO2022_LDFLAGS": "",
    "MODULE__CODECS_ISO2022_STATE": "disabled",
    "MODULE__CODECS_JP_DEPS": "./Modules/cjkcodecs/mappings_jisx0213_pair.h ./Modules/cjkcodecs/alg_jisx0201.h ./Modules/cjkcodecs/emu_jisx0213_2000.h ./Modules/cjkcodecs/mappings_jp.h ./Modules/cjkcodecs/multibytecodec.h ./Modules/cjkcodecs/cjkcodecs.h",
    "MODULE__CODECS_JP_LDFLAGS": "",
    "MODULE__CODECS_JP_STATE": "disabled",
    "MODULE__CODECS_KR_DEPS": "./Modules/cjkcodecs/mappings_kr.h ./Modules/cjkcodecs/multibytecodec.h ./Modules/cjkcodecs/cjkcodecs.h",
    "MODULE__CODECS_KR_LDFLAGS": "",
    "MODULE__CODECS_KR_STATE": "disabled",
    "MODULE__CODECS_LDFLAGS": "",
    "MODULE__CODECS_TW_DEPS": "./Modules/cjkcodecs/mappings_tw.h ./Modules/cjkcodecs/multibytecodec.h ./Modules/cjkcodecs/cjkcodecs.h",
    "MODULE__CODECS_TW_LDFLAGS": "",
    "MODULE__CODECS_TW_STATE": "disabled",
    "MODULE__COLLECTIONS_LDFLAGS": "",
    "MODULE__CONTEXTVARS_LDFLAGS": "",
    "MODULE__CONTEXTVARS_STATE": "disabled",
    "MODULE__CSV_LDFLAGS": "",
    "MODULE__CSV_STATE": "disabled",
    "MODULE__CTYPES_DEPS": "./Modules/_ctypes/ctypes.h",
    "MODULE__CTYPES_MALLOC_CLOSURE": "",
    "MODULE__CTYPES_STATE": "disabled",
    "MODULE__CTYPES_TEST_STATE": "disabled",
    "MODULE__CURSES_DEPS": "./Include/py_curses.h",
    "MODULE__CURSES_PANEL_DEPS": "./Include/py_curses.h",
    "MODULE__CURSES_PANEL_STATE": "disabled",
    "MODULE__CURSES_STATE": "disabled",
    "MODULE__DATETIME_DEPS": "./Include/datetime.h",
    "MODULE__DATETIME_LDFLAGS": "",
    "MODULE__DATETIME_STATE": "disabled",
    "MODULE__DBM_STATE": "disabled",
    "MODULE__DECIMAL_DEPS": "./Modules/_decimal/docstrings.h",
    "MODULE__DECIMAL_STATE": "disabled",
    "MODULE__ELEMENTTREE_DEPS": "./Modules/pyexpat.c",
    "MODULE__ELEMENTTREE_STATE": "disabled",
    "MODULE__FUNCTOOLS_LDFLAGS": "",
    "MODULE__GDBM_STATE": "disabled",
    "MODULE__HASHLIB_DEPS": "./Modules/hashlib.h",
    "MODULE__HASHLIB_STATE": "disabled",
    "MODULE__HEAPQ_LDFLAGS": "",
    "MODULE__HEAPQ_STATE": "disabled",
    "MODULE__INTERPCHANNELS_LDFLAGS": "",
    "MODULE__INTERPCHANNELS_STATE": "disabled",
    "MODULE__INTERPQUEUES_LDFLAGS": "",
    "MODULE__INTERPQUEUES_STATE": "disabled",
    "MODULE__INTERPRETERS_LDFLAGS": "",
    "MODULE__INTERPRETERS_STATE": "disabled",
    "MODULE__IO_DEPS": "./Modules/_io/_iomodule.h",
    "MODULE__IO_LDFLAGS": "",
    "MODULE__IO_STATE": "disabled",
    "MODULE__JSON_LDFLAGS": "",
    "MODULE__JSON_STATE": "disabled",
    "MODULE__LOCALE_LDFLAGS": "",
    "MODULE__LSPROF_LDFLAGS": "",
    "MODULE__LSPROF_STATE": "disabled",
    "MODULE__LZMA_STATE": "disabled",
    "MODULE__MD5_DEPS": "./Modules/hashlib.h \\ Modules/_hacl/Hacl_Hash_MD5.h Modules/_hacl/Hacl_Hash_MD5.c",
    "MODULE__MD5_STATE": "disabled",
    "MODULE__MULTIBYTECODEC_DEPS": "./Modules/cjkcodecs/multibytecodec.h",
    "MODULE__MULTIBYTECODEC_LDFLAGS": "",
    "MODULE__MULTIBYTECODEC_STATE": "disabled",
    "MODULE__MULTIPROCESSING_LDFLAGS": "",
    "MODULE__MULTIPROCESSING_STATE": "disabled",
    "MODULE__OPCODE_LDFLAGS": "",
    "MODULE__OPCODE_STATE": "disabled",
    "MODULE__OPERATOR_LDFLAGS": "",
    "MODULE__PICKLE_LDFLAGS": "",
    "MODULE__PICKLE_STATE": "disabled",
    "MODULE__POSIXSHMEM_STATE": "disabled",
    "MODULE__POSIXSUBPROCESS_LDFLAGS": "",
    "MODULE__POSIXSUBPROCESS_STATE": "disabled",
    "MODULE__QUEUE_LDFLAGS": "",
    "MODULE__QUEUE_STATE": "disabled",
    "MODULE__RANDOM_LDFLAGS": "",
    "MODULE__RANDOM_STATE": "disabled",
    "MODULE__SCPROXY_STATE": "n/a",
    "MODULE__SHA1_DEPS": "./Modules/hashlib.h \\ Modules/_hacl/Hacl_Hash_SHA1.h Modules/_hacl/Hacl_Hash_SHA1.c",
    "MODULE__SHA1_STATE": "disabled",
    "MODULE__SHA2_DEPS": "./Modules/hashlib.h \\ Modules/_hacl/libHacl_Hash_SHA2.a",
    "MODULE__SHA2_STATE": "disabled",
    "MODULE__SHA3_DEPS": "./Modules/hashlib.h \\ Modules/_hacl/Hacl_Hash_SHA3.h Modules/_hacl/Hacl_Hash_SHA3.c",
    "MODULE__SHA3_STATE": "disabled",
    "MODULE__SIGNAL_LDFLAGS": "",
    "MODULE__SOCKET_DEPS": "./Modules/socketmodule.h ./Modules/addrinfo.h ./Modules/getaddrinfo.c ./Modules/getnameinfo.c",
    "MODULE__SOCKET_LDFLAGS": "",
    "MODULE__SOCKET_STATE": "disabled",
    "MODULE__SQLITE3_DEPS": "./Modules/_sqlite/connection.h ./Modules/_sqlite/cursor.h ./Modules/_sqlite/microprotocols.h ./Modules/_sqlite/module.h ./Modules/_sqlite/prepare_protocol.h ./Modules/_sqlite/row.h ./Modules/_sqlite/util.h",
    "MODULE__SQLITE3_STATE": "disabled",
    "MODULE__SRE_LDFLAGS": "",
    "MODULE__SSL_DEPS": "./Modules/_ssl.h ./Modules/_ssl/cert.c ./Modules/_ssl/debughelpers.c ./Modules/_ssl/misc.c ./Modules/_ssl_data_111.h ./Modules/_ssl_data_300.h ./Modules/socketmodule.h",
    "MODULE__SSL_STATE": "disabled",
    "MODULE__STATISTICS_LDFLAGS": "",
    "MODULE__STATISTICS_STATE": "disabled",
    "MODULE__STAT_LDFLAGS": "",
    "MODULE__STRUCT_LDFLAGS": "",
    "MODULE__STRUCT_STATE": "disabled",
    "MODULE__SUGGESTIONS_LDFLAGS": "",
    "MODULE__SYMTABLE_LDFLAGS": "",
    "MODULE__SYSCONFIG_LDFLAGS": "",
    "MODULE__TESTBUFFER_STATE": "disabled",
    "MODULE__TESTCAPI_DEPS": "./Modules/_testcapi/parts.h ./Modules/_testcapi/util.h",
    "MODULE__TESTCAPI_STATE": "disabled",
    "MODULE__TESTCLINIC_LIMITED_STATE": "disabled",
    "MODULE__TESTCLINIC_STATE": "disabled",
    "MODULE__TESTEXTERNALINSPECTION_STATE": "disabled",
    "MODULE__TESTIMPORTMULTIPLE_STATE": "disabled",
    "MODULE__TESTINTERNALCAPI_DEPS": "./Modules/_testinternalcapi/parts.h",
    "MODULE__TESTINTERNALCAPI_STATE": "disabled",
    "MODULE__TESTLIMITEDCAPI_DEPS": "./Modules/_testlimitedcapi/testcapi_long.h ./Modules/_testlimitedcapi/parts.h ./Modules/_testlimitedcapi/util.h",
    "MODULE__TESTLIMITEDCAPI_STATE": "disabled",
    "MODULE__TESTMULTIPHASE_STATE": "disabled",
    "MODULE__TESTSINGLEPHASE_STATE": "disabled",
    "MODULE__THREAD_LDFLAGS": "",
    "MODULE__TKINTER_STATE": "disabled",
    "MODULE__TRACEMALLOC_LDFLAGS": "",
    "MODULE__TYPING_LDFLAGS": "",
    "MODULE__TYPING_STATE": "disabled",
    "MODULE__UUID_STATE": "disabled",
    "MODULE__WEAKREF_LDFLAGS": "",
    "MODULE__XXTESTFUZZ_LDFLAGS": "",
    "MODULE__XXTESTFUZZ_STATE": "disabled",
    "MODULE__ZONEINFO_LDFLAGS": "",
    "MODULE__ZONEINFO_STATE": "disabled",
    "MULTIARCH": "x86_64-linux-gnu",
    "MULTIARCH_CPPFLAGS": "-DMULTIARCH=\\\"x86_64-linux-gnu\\\"",
    "MVWDELCH_IS_EXPRESSION": 1,
    "NO_AS_NEEDED": "-Wl,--no-as-needed",
    "OBJECT_OBJS": "\\",
    "OPT": "-DNDEBUG -g -O3 -Wall",
    "PACKAGE_BUGREPORT": 0,
    "PACKAGE_NAME": 0,
    "PACKAGE_STRING": 0,
    "PACKAGE_TARNAME": 0,
    "PACKAGE_URL": 0,
    "PACKAGE_VERSION": 0,
    "PARSER_HEADERS": "\\",
    "PARSER_OBJS": "\\ \\ \\ Parser/myreadline.o",
    "PEGEN_HEADERS": "\\",
    "PEGEN_OBJS": "\\",
    "PGO_PROF_GEN_FLAG": "-fprofile-instr-generate",
    "PGO_PROF_USE_FLAG": "-fprofile-instr-use=\"$(shell pwd)/code.profclangd\"",
    "PLATLIBDIR": "lib",
    "POBJS": "\\",
    "POSIX_SEMAPHORES_NOT_ENABLED": 0,
    "PROFILE_TASK": "-m test --pgo -j 4 --ignore test.test_bytes.BytesTest.test_from_format",
    "PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT": 1,
    "PTHREAD_SYSTEM_SCHED_SUPPORTED": 1,
    "PURIFY": "",
    "PY3LIBRARY": "libpython3.so",
    "PYLONG_BITS_IN_DIGIT": 0,
    "PYTHON": "python",
    "PYTHONFRAMEWORK": "",
    "PYTHONFRAMEWORKDIR": "no-framework",
    "PYTHONFRAMEWORKINSTALLDIR": "",
    "PYTHONFRAMEWORKINSTALLNAMEPREFIX": "",
    "PYTHONFRAMEWORKPREFIX": "",
    "PYTHONPATH": "",
    "PYTHON_FOR_BUILD": "_PYTHON_PROJECT_BASE=/build/Python-3.13.14 _PYTHON_HOST_PLATFORM=$(_PYTHON_HOST_PLATFORM) PYTHONPATH=./Lib _PYTHON_SYSCONFIGDATA_NAME=_sysconfigdata__linux_x86_64-linux-gnu _PYTHON_SYSCONFIGDATA_PATH=$(shell test -f pybuilddir.txt && echo /build/Python-3.13.14/`cat pybuilddir.txt`) /tools/host/bin/python3.13",
    "PYTHON_FOR_BUILD_DEPS": "",
    "PYTHON_FOR_FREEZE": "/tools/host/bin/python3.13",
    "PYTHON_FOR_REGEN": "",
    "PYTHON_HEADERS": "\\",
    "PYTHON_OBJS": "\\",
    "PY_BUILTIN_HASHLIB_HASHES": "\"md5,sha1,sha2,sha3,blake2\"",
    "PY_BUILTIN_MODULE_CFLAGS": "-fno-strict-overflow -Wsign-compare -Wunreachable-code -DNDEBUG -g -O3 -Wall -O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC   -D_Py_TIER2=3 -D_Py_JIT -flto=thin -g -fno-pie -std=c11 -Wextra -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=/build/Python-3.13.14/code.profclangd -I./Include/internal -I./Include/internal/mimalloc -I. -I./Include -O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC   -fPIC -DPy_BUILD_CORE_BUILTIN",
    "PY_CFLAGS": "-fno-strict-overflow -Wsign-compare -Wunreachable-code -DNDEBUG -g -O3 -Wall -O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC  ",
    "PY_CFLAGS_NODIST": "-D_Py_TIER2=3 -D_Py_JIT -flto=thin -g -fno-pie -std=c11 -Wextra -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=/build/Python-3.13.14/code.profclangd -I./Include/internal -I./Include/internal/mimalloc",
    "PY_COERCE_C_LOCALE": 1,
    "PY_CORE_CFLAGS": "-fno-strict-overflow -Wsign-compare -Wunreachable-code -DNDEBUG -g -O3 -Wall -O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC   -D_Py_TIER2=3 -D_Py_JIT -flto=thin -g -fno-pie -std=c11 -Wextra -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=/build/Python-3.13.14/code.profclangd -I./Include/internal -I./Include/internal/mimalloc -I. -I./Include -O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC   -fPIC -DPy_BUILD_CORE",
    "PY_CORE_LDFLAGS": "-Wl,-z,noexecstack  -Wl,--exclude-libs,ALL  -flto=thin -g -Wl,--emit-relocs",
    "PY_CPPFLAGS": "-I. -I./Include -O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC  ",
    "PY_ENABLE_SHARED": 1,
    "PY_HAVE_PERF_TRAMPOLINE": 1,
    "PY_LDFLAGS": "-Wl,-z,noexecstack  -Wl,--exclude-libs,ALL ",
    "PY_LDFLAGS_NODIST": "-flto=thin -g -Wl,--emit-relocs",
    "PY_LDFLAGS_NOLTO": "-Wl,-z,noexecstack  -Wl,--exclude-libs,ALL  -flto=thin",
    "PY_SQLITE_ENABLE_LOAD_EXTENSION": 0,
    "PY_SQLITE_HAVE_SERIALIZE": 1,
    "PY_SSL_DEFAULT_CIPHERS": 1,
    "PY_SSL_DEFAULT_CIPHER_STRING": 0,
    "PY_STDMODULE_CFLAGS": "-fno-strict-overflow -Wsign-compare -Wunreachable-code -DNDEBUG -g -O3 -Wall -O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC   -D_Py_TIER2=3 -D_Py_JIT -flto=thin -g -fno-pie -std=c11 -Wextra -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=/build/Python-3.13.14/code.profclangd -I./Include/internal -I./Include/internal/mimalloc -I. -I./Include -O3  -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer  -fPIC   -fPIC",
    "PY_SUPPORT_TIER": 2,
    "Py_DEBUG": 0,
    "Py_ENABLE_SHARED": 1,
    "Py_GIL_DISABLED": 0,
    "Py_HASH_ALGORITHM": 0,
    "Py_RL_STARTUP_HOOK_TAKES_ARGS": 0,
    "Py_STATS": 0,
    "Py_SUNOS_VERSION": 0,
    "Py_TRACE_REFS": 0,
    "QUICKTESTOPTS": "-x test_subprocess test_io \\",
    "READELF": "@READELF@",
    "RESSRCDIR": "",
    "RETSIGTYPE": "void",
    "RUNSHARED": "LD_LIBRARY_PATH=/build/Python-3.13.14",
    "SCRIPTDIR": "/install/lib",
    "SCRIPT_IDLE": "build/scripts-3.13/idle3.13",
    "SCRIPT_PYDOC": "build/scripts-3.13/pydoc3.13",
    "SETPGRP_HAVE_ARG": 0,
    "SHAREDMODS": "Modules/_ctypes_test.cpython-313-x86_64-linux-gnu.so Modules/_dbm.cpython-313-x86_64-linux-gnu.so Modules/_testbuffer.cpython-313-x86_64-linux-gnu.so Modules/_testcapi.cpython-313-x86_64-linux-gnu.so Modules/_testexternalinspection.cpython-313-x86_64-linux-gnu.so Modules/_testimportmultiple.cpython-313-x86_64-linux-gnu.so Modules/_testlimitedcapi.cpython-313-x86_64-linux-gnu.so Modules/_testmultiphase.cpython-313-x86_64-linux-gnu.so Modules/_testsinglephase.cpython-313-x86_64-linux-gnu.so Modules/_tkinter.cpython-313-x86_64-linux-gnu.so",
    "SHELL": "/bin/sh -e",
    "SHLIBS": "-lpthread -ldl  -lutil",
    "SHLIB_SUFFIX": ".so",
    "SIGNED_RIGHT_SHIFT_ZERO_FILLS": 0,
    "SITEPATH": "",
    "SIZEOF_DOUBLE": 8,
    "SIZEOF_FLOAT": 4,
    "SIZEOF_FPOS_T": 16,
    "SIZEOF_INT": 4,
    "SIZEOF_LONG": 8,
    "SIZEOF_LONG_DOUBLE": 16,
    "SIZEOF_LONG_LONG": 8,
    "SIZEOF_OFF_T": 8,
    "SIZEOF_PID_T": 4,
    "SIZEOF_PTHREAD_KEY_T": 4,
    "SIZEOF_PTHREAD_T": 8,
    "SIZEOF_SHORT": 2,
    "SIZEOF_SIZE_T": 8,
    "SIZEOF_TIME_T": 8,
    "SIZEOF_UINTPTR_T": 8,
    "SIZEOF_VOID_P": 8,
    "SIZEOF_WCHAR_T": 4,
    "SIZEOF__BOOL": 1,
    "SOABI": "cpython-313-x86_64-linux-gnu",
    "SRCDIRS": "Modules   Modules/_blake2   Modules/_ctypes   Modules/_decimal   Modules/_decimal/libmpdec   Modules/_hacl   Modules/_io   Modules/_multiprocessing   Modules/_sqlite   Modules/_sre   Modules/_testcapi   Modules/_testinternalcapi   Modules/_testlimitedcapi   Modules/_xxtestfuzz   Modules/cjkcodecs   Modules/expat   Objects   Objects/mimalloc   Objects/mimalloc/prim   Parser   Parser/tokenizer   Parser/lexer   Programs   Python   Python/frozen_modules",
    "SRC_GDB_HOOKS": "./Tools/gdb/libpython.py",
    "STATIC_LIBPYTHON": 1,
    "STDC_HEADERS": 1,
    "STRICT_SYSV_CURSES": "/* Don't use ncurses extensions */",
    "STRIPFLAG": "-s",
    "SUBDIRS": "",
    "SUBDIRSTOO": "Include Lib Misc",
    "SYSLIBS": "-lm",
    "SYS_SELECT_WITH_SYS_TIME": 1,
    "TESTOPTS": "",
    "TESTPATH": "",
    "TESTPYTHON": "LD_LIBRARY_PATH=/build/Python-3.13.14 _PYTHON_PROJECT_BASE=/build/Python-3.13.14 _PYTHON_HOST_PLATFORM=$(_PYTHON_HOST_PLATFORM) PYTHONPATH=./Lib _PYTHON_SYSCONFIGDATA_NAME=_sysconfigdata__linux_x86_64-linux-gnu _PYTHON_SYSCONFIGDATA_PATH=$(shell test -f pybuilddir.txt && echo /build/Python-3.13.14/`cat pybuilddir.txt`) /tools/host/bin/python3.13",
    "TESTPYTHONOPTS": "",
    "TESTRUNNER": "LD_LIBRARY_PATH=/build/Python-3.13.14 _PYTHON_PROJECT_BASE=/build/Python-3.13.14 _PYTHON_HOST_PLATFORM=$(_PYTHON_HOST_PLATFORM) PYTHONPATH=./Lib _PYTHON_SYSCONFIGDATA_NAME=_sysconfigdata__linux_x86_64-linux-gnu _PYTHON_SYSCONFIGDATA_PATH=$(shell test -f pybuilddir.txt && echo /build/Python-3.13.14/`cat pybuilddir.txt`) /tools/host/bin/python3.13 -m test",
    "TESTSUBDIRS": "idlelib/idle_test \\",
    "TESTTIMEOUT": "",
    "TEST_MODULES": "yes",
    "THREAD_STACK_SIZE": 0,
    "TIMEMODULE_LIB": 0,
    "TM_IN_SYS_TIME": 0,
    "TOKENIZER_HEADERS": "\\",
    "TOKENIZER_OBJS": "\\",
    "TZPATH": "/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo",
    "UNICODE_DEPS": "\\",
    "UNIVERSALSDK": "",
    "UPDATE_FILE": "./Tools/build/update_file.py",
    "USE_COMPUTED_GOTOS": 0,
    "VERSION": "3.13",
    "WASM_ASSETS_DIR": "./install",
    "WASM_STDLIB": "./install/lib/python3.13/os.py",
    "WHEEL_PKG_DIR": "",
    "WINDOW_HAS_FLAGS": 0,
    "WITH_DECIMAL_CONTEXTVAR": 1,
    "WITH_DOC_STRINGS": 1,
    "WITH_DTRACE": 0,
    "WITH_DYLD": 0,
    "WITH_EDITLINE": 1,
    "WITH_FREELISTS": 1,
    "WITH_LIBINTL": 0,
    "WITH_MIMALLOC": 1,
    "WITH_NEXT_FRAMEWORK": 0,
    "WITH_PYMALLOC": 1,
    "WITH_VALGRIND": 0,
    "X87_DOUBLE_ROUNDING": 0,
    "XMLLIBSUBDIRS": "xml xml/dom xml/etree xml/parsers xml/sax",
    "abs_builddir": "/build/Python-3.13.14",
    "abs_srcdir": "/build/Python-3.13.14",
    "datarootdir": "/install/share",
    "exec_prefix": "/install",
    "prefix": "/install",
    "srcdir": "."
}